==> MediaWikiLanguageExtensionBundle-2012.12.tar.bz2: extensions/cldr/CldrNames/CldrNamesSg.php <==
<?php

$languageNames = array(
'ak' => 'Akâan',
'am' => 'Amarîki',
'ar' => 'Arâbo',
'be' => 'Bielörûsi',
'bg' => 'Bulugäri',
'bn' => 'Bengäli',
'cs' => 'Tyêki',
'de' => 'Zâmani',
'el' => 'Gerêki',
'en' => 'Anglëe',
'es' => 'Espanyöl',
'fa' => 'Farsî',
'fr' => 'Farânzi',
'ha' => 'Haüsä',
'hi' => 'Hîndi',
'hu' => 'Hongruäa',
'id' => 'Enndonezïi',
'ig' => 'Ïgbö',
'it' => 'Ênnde',
'ja' => 'Zaponëe',
'jv' => 'Zavanëe',
'km' => 'Kmêre',
'ko' => 'Koreyëen',
'ms' => 'Malëe',
'my' => 'Miamära, Birimäni',
'ne' => 'Nepalëe',
'nl' => 'Holandëe',
'pa' => 'Penzäbï',
'pl' => 'Polonëe',
'pt' => 'Portugëe, Pûra',
'ro' => 'Rumëen',
'ru' => 'Rûsi',
'rw' => 'Ruandäa',
'sg' => 'Sängö',
'so' => 'Somalïi',
'sv' => 'Sueduäa',
'ta' => 'Tämûli',
'th' => 'Thâi',
'tr' => 'Tûrûku',
'uk' => 'Ukrêni',
'ur' => 'Ûrdu',
'vi' => 'Vietnäm',
'yo' => 'Yoruba',
'zh' => 'Shinuäa',
'zu' => 'Zûlu',
);

$currencyNames = array(
'AED' => 'dirâm tî âEmirâti tî Arâbo Ôko',
'AOA' => 'kwânza tî Angoläa',
'AUD' => 'dolära tî Ostralïi',
'BHD' => 'dolùara tî Bahrâina',
'BIF' => 'farânga tî Burundïi',
'BWP' => 'pûla tî Botswana',
'CAD' => 'dolära tî kanadäa',
'CDF' => 'farânga tî Kongöo',
'CHF' => 'farânga tî Sûîsi',
'CNY' => 'yuan renminbi tî Shîni',
'CVE' => 'eskûêdo tî Kâpo-Vêre',
'DJF' => 'farânga tî Dibutïi',
'DZD' => 'dinäri tî Alzerïi',
'EGP' => 'pôndo tî Kâmitâ',
'ERN' => 'nakafa tî Eritrëe',
'ETB' => 'bir tî Etiopïi',
'EUR' => 'zoröo',
'GBP' => 'pôndo tî Anglëe',
'GHC' => 'sêdi tî Ganäa',
'GMD' => 'dalasi tî gambïi',
'GNS' => 'sili tî Ginëe',
'INR' => 'rupïi tî Ênnde',
'JPY' => 'yêni tî Zapön',
'KES' => 'shilîngi tî Kenyäa',
'KMF' => 'farânga tî Kömôro',
'LRD' => 'dolära tî Liberïa',
'LSL' => 'loti tî Lesôtho',
'LYD' => 'dinäar tî Libïi',
'MAD' => 'dirâm tî Marôko',
'MGA' => 'ariâri tî Madagasikära',
'MRO' => 'ugîya tî Moritanïi',
'MUR' => 'rupïi tî Mörîsi',
'MWK' => 'kwâtia tî Malawïi',
'MZM' => 'metikala tî Mozambîka',
'NAD' => 'dolära tî Namibïi',
'NGN' => 'nâîra tî Nizerïa',
'RWF' => 'farânga tî Ruandäa',
'SAR' => 'riâli tî Saûdi Arabïi',
'SCR' => 'rupïi tî Sëyshêle',
'SDG' => 'pôndo tî Sudäan',
'SHP' => 'pôndo tî Zûâ Sênt-Helêna',
'SLL' => 'leône tî Sierâ-Leône',
'SOS' => 'shilîngi tî Somalïi',
'STD' => 'dôbra tî Sâô Tomë na Prinsîpe',
'SZL' => 'lilangùeni tî Swazïlânde',
'TND' => 'dinära tî Tunizïi',
'TZS' => 'shilîngi tî Tanzanïi',
'UGX' => 'shilîngi tî Ugandäa',
'USD' => 'dol$ara ttî äLetäa-Ôko tî Amerîka',
'XAF' => 'farânga CFA (BEAC)',
'XOF' => 'farânga CFA (BCEAO)',
'ZAR' => 'rânde tî Mbongo-Afrîka',
'ZMK' => 'kwâtia tî Zambïi',
'ZWD' => 'dolära tî Zimbäbwe',
);

$countryNames = array(
'AD' => 'Andôro',
'AE' => 'Arâbo Emirâti Ôko',
'AF' => 'Faganïta, Afganïstäan',
'AG' => 'Antîgua na Barbûda',
'AI' => 'Angûîla',
'AL' => 'Albanïi',
'AM' => 'Armenïi',
'AN' => 'Antîyi tî Holânde',
'AO' => 'Angoläa',
'AR' => 'Arzantîna',
'AS' => 'Samöa tî Amerîka',
'AT' => 'Otrîsi',
'AU' => 'Ostralïi, Sotralïi',
'AW' => 'Arûba',
'AZ' => 'Zerebaidyäan, Azerbaidyäan,',
'BA' => 'Bosnïi na Herzegovînni',
'BB' => 'Barabâda',
'BD' => 'Bengladêshi',
'BE' => 'Bêleze, Belezîki',
'BF' => 'Burkina Faso',
'BG' => 'Bulugarïi',
'BH' => 'Bahrâina',
'BI' => 'Burundïi',
'BJ' => 'Benëen',
'BM' => 'Beremûda',
'BN' => 'Brunêi',
'BO' => 'Bolivïi',
'BR' => 'Brezîli',
'BS' => 'Bahâmasa',
'BT' => 'Butäan',
'BW' => 'Botswana',
'BY' => 'Belarüsi',
'BZ' => 'Belîzi',
'CA' => 'Kanadäa',
'CD' => 'Ködörösêse tî Ngunuhalëzo tî kongö',
'CF' => 'Ködörösêse tî Bêafrîka',
'CG' => 'Kongö',
'CH' => 'Sûîsi',
'CI' => 'Kôdivüära',
'CK' => 'âzûâ Kûku',
'CL' => 'Shilïi',
'CM' => 'Kamerûne',
'CN' => 'Shîna',
'CO' => 'Kolombïi',
'CR' => 'Kôsta Rîka',
'CU' => 'Kubäa',
'CV' => 'Azûâ tî Kâpo-Vêre',
'CY' => 'Sîpri',
'CZ' => 'Ködörösêse tî Tyêki',
'DE' => 'Zâmani',
'DJ' => 'Dibutùii',
'DK' => 'Danemêrke',
'DM' => 'Dömïnîka',
'DO' => 'Ködörösêse tî Dominîka',
'DZ' => 'Alzerïi',
'EC' => 'Ekuatëre',
'EE' => 'Estonïi',
'EG' => 'Kâmitâ',
'ER' => 'Eritrëe',
'ES' => 'Espânye',
'ET' => 'Etiopïi',
'FI' => 'Fëlânde',
'FJ' => 'Fidyïi',
'FK' => 'Âzûâ tî Mälüîni',
'FM' => 'Mikronezïi',
'FR' => 'Farânzi',
'GA' => 'Gaböon',
'GB' => 'Ködörögbïä--Ôko',
'GD' => 'Grenâda',
'GE' => 'Zorzïi',
'GF' => 'Güyâni tî farânzi',
'GH' => 'Ganäa',
'GI' => 'Zibraltära, Zibaratära',
'GL' => 'Gorolânde',
'GM' => 'Gambïi',
'GN' => 'Ginëe',
'GP' => 'Guadelûpu',
'GQ' => 'Ginëe tî Ekuatëre',
'GR' => 'Gerêsi',
'GT' => 'Guatêmälä',
'GU' => 'Guâm',
'GW' => 'Gninëe-Bisau',
'GY' => 'Gayâna',
'HN' => 'Honduräsi',
'HR' => 'Kroasïi',
'HT' => 'Haitïi',
'HU' => 'Hongirùii',
'ID' => 'Ênndonezïi',
'IE' => 'Irlânde',
'IL' => 'Israëli',
'IN' => 'Ênnde',
'IO' => 'Sêse tî Anglëe na Ngûyämä tî Ênnde',
'IQ' => 'Irâki',
'IR' => 'Iräan',
'IS' => 'Islânde',
'IT' => 'Italùii',
'JM' => 'Zamaîka',
'JO' => 'Zordanïi',
'JP' => 'Zapöon',
'KE' => 'Kenyäa',
'KG' => 'Kirigizitùaan',
'KH' => 'Kämbôzi',
'KI' => 'Kiribati',
'KM' => 'Kömôro',
'KN' => 'Sên-Krïstôfo-na-Nevîsi',
'KP' => 'Korëe tî Banga',
'KR' => 'Korëe tî Mbongo',
'KW' => 'Köwêti',
'KY' => 'Âzûâ Ngundë, Kaimäni',
'KZ' => 'Kazakisitäan',
'LA' => 'Lùaôsi',
'LB' => 'Libùaan',
'LC' => 'Sênt-Lisïi',
'LI' => 'Liechtenstein,',
'LK' => 'Sirî-Lanka',
'LR' => 'Liberïa',
'LS' => 'Lesôtho',
'LT' => 'Lituanïi',
'LU' => 'Lugzambûru',
'LV' => 'Letonùii',
'LY' => 'Libïi',
'MA' => 'Marôko',
'MC' => 'Monaköo',
'MD' => 'Moldavùii',
'MG' => 'Madagaskära',
'MH' => 'Âzûâ Märshâl',
'MK' => 'Maseduäni',
'ML' => 'Malïi',
'MM' => 'Myämâra',
'MN' => 'Mongolïi',
'MP' => 'Âzûâ Märïâni tî Banga',
'MQ' => 'Märtïnîki',
'MR' => 'Moritanïi',
'MS' => 'Monserâte',
'MT' => 'Mâlta',
'MU' => 'Mörîsi',
'MV' => 'Maldîva',
'MW' => 'Malawïi',
'MX' => 'Mekisîki',
'MY' => 'Malezïi',
'MZ' => 'Mözämbîka',
'NA' => 'Namibùii',
'NC' => 'Finî Kaledonïi',
'NE' => 'Nizëre',
'NF' => 'Zûâ Nôrfôlko',
'NG' => 'Nizerïa',
'NI' => 'Nikaragua',
'NL' => 'Holände',
'NO' => 'Nörvêzi',
'NP' => 'Nëpâli',
'NR' => 'Nauru',
'NU' => 'Niue',
'NZ' => 'Finî Zelânde',
'OM' => 'Omâni',
'PA' => 'Panama',
'PE' => 'Perüu',
'PF' => 'Polinezïi tî farânzi',
'PG' => 'Papû Finî Ginëe, Papuazïi',
'PH' => 'Filipîni',
'PK' => 'Pakistäan',
'PL' => 'Pölôni',
'PM' => 'Sên-Pyêre na Mikelöon',
'PN' => 'Pitikêrni',
'PR' => 'Porto Rîko',
'PS' => 'Sêse tî Palestîni',
'PT' => 'Pörtugäle, Ködörö Pûra',
'PW' => 'Palau',
'PY' => 'Paraguëe',
'QA' => 'Katära',
'RE' => 'Reinïon',
'RO' => 'Rumanïi',
'RU' => 'Rusïi',
'RW' => 'Ruandäa',
'SA' => 'Saûdi Arabïi',
'SB' => 'Zûâ Salomöon',
'SC' => 'Sëyshêle',
'SD' => 'Sudäan',
'SE' => 'Suêde',
'SG' => 'Sïngäpûru',
'SH' => 'Sênt-Helêna',
'SI' => 'Solovenïi',
'SK' => 'Solovakïi',
'SL' => 'Sierä-Leône',
'SM' => 'Sên-Marëen',
'SN' => 'Senegäle',
'SO' => 'Somalïi',
'SR' => 'Surinäm',
'SS' => 'Sudäan-Mbongo',
'ST' => 'Sâô Tömê na Prinsîpe',
'SV' => 'Salvadöro',
'SY' => 'Sirïi',
'SZ' => 'Swäzïlânde',
'TC' => 'Âzûâ Turku na Kaîki',
'TD' => 'Tyâde',
'TG' => 'Togö',
'TH' => 'Tailânde',
'TJ' => 'Taazikiistäan',
'TK' => 'Tokelau',
'TL' => 'Timôro tî Tö',
'TM' => 'Turkumenistäan',
'TN' => 'Tunizïi',
'TO' => 'Tonga',
'TR' => 'Turukïi',
'TT' => 'Trinitùee na Tobagö',
'TV' => 'Tüvalü',
'TW' => 'Tâiwâni',
'TZ' => 'Tanzanïi',
'UA' => 'Ukrêni',
'UG' => 'Ugandäa',
'US' => 'ÂLeaa-Ôko tî Amerika',
'UY' => 'Uruguëe',
'UZ' => 'Uzbekistäan',
'VA' => 'Letëe tî Vatikäan',
'VC' => 'Sên-Vensäan na âGrenadîni',
'VE' => 'Venezueläa',
'VG' => 'Âzôâ Viîrîggo tî Anglëe',
'VI' => 'Âzûâ Virîgo tî Amerîka',
'VN' => 'Vietnäm',
'VU' => 'Vanuatü',
'WF' => 'Walîsi na Futuna',
'WS' => 'Samoäa',
'YE' => 'Yëmêni',
'YT' => 'Mäyôte',
'ZA' => 'Mbongo-Afrîka',
'ZM' => 'Zambïi',
'ZW' => 'Zimbäbwe',
);

==> MediaWikiLanguageExtensionBundle-2013.05.tar.bz2: extensions/cldr/CldrNames/CldrNamesSg.php <==
<?php

$languageNames = array(
'ak' => 'Akâan',
'am' => 'Amarîki',
'ar' => 'Arâbo',
'be' => 'Bielörûsi',
'bg' => 'Bulugäri',
'bn' => 'Bengäli',
'cs' => 'Tyêki',
'de' => 'Zâmani',
'el' => 'Gerêki',
'en' => 'Anglëe',
'es' => 'Espanyöl',
'fa' => 'Farsî',
'fr' => 'Farânzi',
'ha' => 'Haüsä',
'hi' => 'Hîndi',
'hu' => 'Hongruäa',
'id' => 'Enndonezïi',
'ig' => 'Ïgbö',
'it' => 'Ênnde',
'ja' => 'Zaponëe',
'jv' => 'Zavanëe',
'km' => 'Kmêre',
'ko' => 'Koreyëen',
'ms' => 'Malëe',
'my' => 'Miamära, Birimäni',
'ne' => 'Nepalëe',
'nl' => 'Holandëe',
'pa' => 'Penzäbï',
'pl' => 'Polonëe',
'pt' => 'Portugëe, Pûra',
'ro' => 'Rumëen',
'ru' => 'Rûsi',
'rw' => 'Ruandäa',
'sg' => 'Sängö',
'so' => 'Somalïi',
'sv' => 'Sueduäa',
'ta' => 'Tämûli',
'th' => 'Thâi',
'tr' => 'Tûrûku',
'uk' => 'Ukrêni',
'ur' => 'Ûrdu',
'vi' => 'Vietnäm',
'yo' => 'Yoruba',
'zh' => 'Shinuäa',
'zu' => 'Zûlu',
);

$currencyNames = array(
'AED' => 'dirâm tî âEmirâti tî Arâbo Ôko',
'AOA' => 'kwânza tî Angoläa',
'AUD' => 'dolära tî Ostralïi',
'BHD' => 'dolùara tî Bahrâina',
'BIF' => 'farânga tî Burundïi',
'BWP' => 'pûla tî Botswana',
'CAD' => 'dolära tî kanadäa',
'CDF' => 'farânga tî Kongöo',
'CHF' => 'farânga tî Sûîsi',
'CNY' => 'yuan renminbi tî Shîni',
'CVE' => 'eskûêdo tî Kâpo-Vêre',
'DJF' => 'farânga tî Dibutïi',
'DZD' => 'dinäri tî Alzerïi',
'EGP' => 'pôndo tî Kâmitâ',
'ERN' => 'nakafa tî Eritrëe',
'ETB' => 'bir tî Etiopïi',
'EUR' => 'zoröo',
'GBP' => 'pôndo tî Anglëe',
'GHC' => 'sêdi tî Ganäa',
'GMD' => 'dalasi tî gambïi',
'GNS' => 'sili tî Ginëe',
'INR' => 'rupïi tî Ênnde',
'JPY' => 'yêni tî Zapön',
'KES' => 'shilîngi tî Kenyäa',
'KMF' => 'farânga tî Kömôro',
'LRD' => 'dolära tî Liberïa',
'LSL' => 'loti tî Lesôtho',
'LYD' => 'dinäar tî Libïi',
'MAD' => 'dirâm tî Marôko',
'MGA' => 'ariâri tî Madagasikära',
'MRO' => 'ugîya tî Moritanïi',
'MUR' => 'rupïi tî Mörîsi',
'MWK' => 'kwâtia tî Malawïi',
'MZM' => 'metikala tî Mozambîka',
'NAD' => 'dolära tî Namibïi',
'NGN' => 'nâîra tî Nizerïa',
'RWF' => 'farânga tî Ruandäa',
'SAR' => 'riâli tî Saûdi Arabïi',
'SCR' => 'rupïi tî Sëyshêle',
'SDG' => 'pôndo tî Sudäan',
'SHP' => 'pôndo tî Zûâ Sênt-Helêna',
'SLL' => 'leône tî Sierâ-Leône',
'SOS' => 'shilîngi tî Somalïi',
'STD' => 'dôbra tî Sâô Tomë na Prinsîpe',
'SZL' => 'lilangùeni tî Swazïlânde',
'TND' => 'dinära tî Tunizïi',
'TZS' => 'shilîngi tî Tanzanïi',
'UGX' => 'shilîngi tî Ugandäa',
'USD' => 'dol$ara ttî äLetäa-Ôko tî Amerîka',
'XAF' => 'farânga CFA (BEAC)',
'XOF' => 'farânga CFA (BCEAO)',
'ZAR' => 'rânde tî Mbongo-Afrîka',
'ZMK' => 'kwâtia tî Zambïi (1968-2012)',
'ZMW' => 'kwâtia tî Zambïi',
'ZWD' => 'dolära tî Zimbäbwe',
);

$countryNames = array(
'AD' => 'Andôro',
'AE' => 'Arâbo Emirâti Ôko',
'AF' => 'Faganïta, Afganïstäan',
'AG' => 'Antîgua na Barbûda',
'AI' => 'Angûîla',
'AL' => 'Albanïi',
'AM' => 'Armenïi',
'AN' => 'Antîyi tî Holânde',
'AO' => 'Angoläa',
'AR' => 'Arzantîna',
'AS' => 'Samöa tî Amerîka',
'AT' => 'Otrîsi',
'AU' => 'Ostralïi, Sotralïi',
'AW' => 'Arûba',
'AZ' => 'Zerebaidyäan, Azerbaidyäan,',
'BA' => 'Bosnïi na Herzegovînni',
'BB' => 'Barabâda',
'BD' => 'Bengladêshi',
'BE' => 'Bêleze, Belezîki',
'BF' => 'Burkina Faso',
'BG' => 'Bulugarïi',
'BH' => 'Bahrâina',
'BI' => 'Burundïi',
'BJ' => 'Benëen',
'BM' => 'Beremûda',
'BN' => 'Brunêi',
'BO' => 'Bolivïi',
'BR' => 'Brezîli',
'BS' => 'Bahâmasa',
'BT' => 'Butäan',
'BW' => 'Botswana',
'BY' => 'Belarüsi',
'BZ' => 'Belîzi',
'CA' => 'Kanadäa',
'CD' => 'Ködörösêse tî Ngunuhalëzo tî kongö',
'CF' => 'Ködörösêse tî Bêafrîka',
'CG' => 'Kongö',
'CH' => 'Sûîsi',
'CI' => 'Kôdivüära',
'CK' => 'âzûâ Kûku',
'CL' => 'Shilïi',
'CM' => 'Kamerûne',
'CN' => 'Shîna',
'CO' => 'Kolombïi',
'CR' => 'Kôsta Rîka',
'CU' => 'Kubäa',
'CV' => 'Azûâ tî Kâpo-Vêre',
'CY' => 'Sîpri',
'CZ' => 'Ködörösêse tî Tyêki',
'DE' => 'Zâmani',
'DJ' => 'Dibutùii',
'DK' => 'Danemêrke',
'DM' => 'Dömïnîka',
'DO' => 'Ködörösêse tî Dominîka',
'DZ' => 'Alzerïi',
'EC' => 'Ekuatëre',
'EE' => 'Estonïi',
'EG' => 'Kâmitâ',
'ER' => 'Eritrëe',
'ES' => 'Espânye',
'ET' => 'Etiopïi',
'FI' => 'Fëlânde',
'FJ' => 'Fidyïi',
'FK' => 'Âzûâ tî Mälüîni',
'FM' => 'Mikronezïi',
'FR' => 'Farânzi',
'GA' => 'Gaböon',
'GB' => 'Ködörögbïä--Ôko',
'GD' => 'Grenâda',
'GE' => 'Zorzïi',
'GF' => 'Güyâni tî farânzi',
'GH' => 'Ganäa',
'GI' => 'Zibraltära, Zibaratära',
'GL' => 'Gorolânde',
'GM' => 'Gambïi',
'GN' => 'Ginëe',
'GP' => 'Guadelûpu',
'GQ' => 'Ginëe tî Ekuatëre',
'GR' => 'Gerêsi',
'GT' => 'Guatêmälä',
'GU' => 'Guâm',
'GW' => 'Gninëe-Bisau',
'GY' => 'Gayâna',
'HN' => 'Honduräsi',
'HR' => 'Kroasïi',
'HT' => 'Haitïi',
'HU' => 'Hongirùii',
'ID' => 'Ênndonezïi',
'IE' => 'Irlânde',
'IL' => 'Israëli',
'IN' => 'Ênnde',
'IO' => 'Sêse tî Anglëe na Ngûyämä tî Ênnde',
'IQ' => 'Irâki',
'IR' => 'Iräan',
'IS' => 'Islânde',
'IT' => 'Italùii',
'JM' => 'Zamaîka',
'JO' => 'Zordanïi',
'JP' => 'Zapöon',
'KE' => 'Kenyäa',
'KG' => 'Kirigizitùaan',
'KH' => 'Kämbôzi',
'KI' => 'Kiribati',
'KM' => 'Kömôro',
'KN' => 'Sên-Krïstôfo-na-Nevîsi',
'KP' => 'Korëe tî Banga',
'KR' => 'Korëe tî Mbongo',
'KW' => 'Köwêti',
'KY' => 'Âzûâ Ngundë, Kaimäni',
'KZ' => 'Kazakisitäan',
'LA' => 'Lùaôsi',
'LB' => 'Libùaan',
'LC' => 'Sênt-Lisïi',
'LI' => 'Liechtenstein,',
'LK' => 'Sirî-Lanka',
'LR' => 'Liberïa',
'LS' => 'Lesôtho',
'LT' => 'Lituanïi',
'LU' => 'Lugzambûru',
'LV' => 'Letonùii',
'LY' => 'Libïi',
'MA' => 'Marôko',
'MC' => 'Monaköo',
'MD' => 'Moldavùii',
'MG' => 'Madagaskära',
'MH' => 'Âzûâ Märshâl',
'MK' => 'Maseduäni',
'ML' => 'Malïi',
'MM' => 'Myämâra',
'MN' => 'Mongolïi',
'MP' => 'Âzûâ Märïâni tî Banga',
'MQ' => 'Märtïnîki',
'MR' => 'Moritanïi',
'MS' => 'Monserâte',
'MT' => 'Mâlta',
'MU' => 'Mörîsi',
'MV' => 'Maldîva',
'MW' => 'Malawïi',
'MX' => 'Mekisîki',
'MY' => 'Malezïi',
'MZ' => 'Mözämbîka',
'NA' => 'Namibùii',
'NC' => 'Finî Kaledonïi',
'NE' => 'Nizëre',
'NF' => 'Zûâ Nôrfôlko',
'NG' => 'Nizerïa',
'NI' => 'Nikaragua',
'NL' => 'Holände',
'NO' => 'Nörvêzi',
'NP' => 'Nëpâli',
'NR' => 'Nauru',
'NU' => 'Niue',
'NZ' => 'Finî Zelânde',
'OM' => 'Omâni',
'PA' => 'Panama',
'PE' => 'Perüu',
'PF' => 'Polinezïi tî farânzi',
'PG' => 'Papû Finî Ginëe, Papuazïi',
'PH' => 'Filipîni',
'PK' => 'Pakistäan',
'PL' => 'Pölôni',
'PM' => 'Sên-Pyêre na Mikelöon',
'PN' => 'Pitikêrni',
'PR' => 'Porto Rîko',
'PS' => 'Sêse tî Palestîni',
'PT' => 'Pörtugäle, Ködörö Pûra',
'PW' => 'Palau',
'PY' => 'Paraguëe',
'QA' => 'Katära',
'RE' => 'Reinïon',
'RO' => 'Rumanïi',
'RU' => 'Rusïi',
'RW' => 'Ruandäa',
'SA' => 'Saûdi Arabïi',
'SB' => 'Zûâ Salomöon',
'SC' => 'Sëyshêle',
'SD' => 'Sudäan',
'SE' => 'Suêde',
'SG' => 'Sïngäpûru',
'SH' => 'Sênt-Helêna',
'SI' => 'Solovenïi',
'SK' => 'Solovakïi',
'SL' => 'Sierä-Leône',
'SM' => 'Sên-Marëen',
'SN' => 'Senegäle',
'SO' => 'Somalïi',
'SR' => 'Surinäm',
'SS' => 'Sudäan-Mbongo',
'ST' => 'Sâô Tömê na Prinsîpe',
'SV' => 'Salvadöro',
'SY' => 'Sirïi',
'SZ' => 'Swäzïlânde',
'TC' => 'Âzûâ Turku na Kaîki',
'TD' => 'Tyâde',
'TG' => 'Togö',
'TH' => 'Tailânde',
'TJ' => 'Taazikiistäan',
'TK' => 'Tokelau',
'TL' => 'Timôro tî Tö',
'TM' => 'Turkumenistäan',
'TN' => 'Tunizïi',
'TO' => 'Tonga',
'TR' => 'Turukïi',
'TT' => 'Trinitùee na Tobagö',
'TV' => 'Tüvalü',
'TW' => 'Tâiwâni',
'TZ' => 'Tanzanïi',
'UA' => 'Ukrêni',
'UG' => 'Ugandäa',
'US' => 'ÂLeaa-Ôko tî Amerika',
'UY' => 'Uruguëe',
'UZ' => 'Uzbekistäan',
'VA' => 'Letëe tî Vatikäan',
'VC' => 'Sên-Vensäan na âGrenadîni',
'VE' => 'Venezueläa',
'VG' => 'Âzôâ Viîrîggo tî Anglëe',
'VI' => 'Âzûâ Virîgo tî Amerîka',
'VN' => 'Vietnäm',
'VU' => 'Vanuatü',
'WF' => 'Walîsi na Futuna',
'WS' => 'Samoäa',
'YE' => 'Yëmêni',
'YT' => 'Mäyôte',
'ZA' => 'Mbongo-Afrîka',
'ZM' => 'Zambïi',
'ZW' => 'Zimbäbwe',
);
